Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: webrtc/modules/video_render/mac/video_render_agl.h

Issue 1738863002: Replace scoped_ptr with unique_ptr in webrtc/modules/video_*/ (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@up4
Patch Set: rebase Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/video_render/mac/video_render_agl.h
diff --git a/webrtc/modules/video_render/mac/video_render_agl.h b/webrtc/modules/video_render/mac/video_render_agl.h
index e1da8faf83b81da6c58944f9185b366631920545..c0a60597e98613d22ba1581a096cbd46e02f5466 100644
--- a/webrtc/modules/video_render/mac/video_render_agl.h
+++ b/webrtc/modules/video_render/mac/video_render_agl.h
@@ -29,6 +29,7 @@
#include <OpenGL/glu.h>
#include <list>
#include <map>
+#include <memory>
class VideoRenderAGL;
@@ -142,8 +143,8 @@ class VideoRenderAGL {
bool _fullScreen;
int _id;
webrtc::CriticalSectionWrapper& _renderCritSec;
- // TODO(pbos): Remove scoped_ptr and use PlatformThread directly.
- rtc::scoped_ptr<rtc::PlatformThread> _screenUpdateThread;
+ // TODO(pbos): Remove unique_ptr and use PlatformThread directly.
+ std::unique_ptr<rtc::PlatformThread> _screenUpdateThread;
webrtc::EventWrapper* _screenUpdateEvent;
bool _isHIViewRef;
AGLContext _aglContext;
« no previous file with comments | « webrtc/modules/video_render/ios/video_render_ios_view.mm ('k') | webrtc/modules/video_render/mac/video_render_nsopengl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698